BaseGuard

Trait BaseGuard 

pub trait BaseGuard {
    type State: Clone + Copy;

    // Required methods
    fn acquire() -> Self::State;
    fn release(state: Self::State);
}
A base trait that all guards implement.

Required Associated Types

type State: Clone + Copy

The saved state when entering the critical section.

Required Methods

fn acquire() -> Self::State

Something that must be done before entering the critical section.

fn release(state: Self::State)

Something that must be done after leaving the critical section.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors